@@ -11,7 +11,7 @@ use vars qw(@EXPORT @EXPORT_OK @ISA $VERSION);
 BEGIN {
     require Exporter;
     @ISA = qw(Exporter);
-    $VERSION = '1.04';
+    $VERSION = '1.05';
     @EXPORT = @EXPORT_OK = qw(rd_f wr_f ap_f find_home find_temp find_bin lockafile unlockafile unlock_all_the_files);
 }
 
@@ -100,10 +100,11 @@ sub rd_f {
         return undef;
     }
     $! = 0;
-    unless (open($fh, '<:raw', $fn)) {
+    unless (open($fh, '<:raw:bytes', $fn)) {
         ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', "cannot open for reading", $!, 0+$!);
         return undef;
     }
+    binmode($fh);
     my $file_size = -s $fn;
     if ($file_size) {
         my $n_bytes = read($fh, $buf, $file_size);
@@ -137,10 +138,11 @@ sub wr_f {
         return undef;
     }
     $! = 0;
-    unless (open($fh, '>:raw', $fn)) {
+    unless (open($fh, '>:raw:bytes', $fn)) {
         ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', "cannot open for writing", $!, 0+$!);
         return undef;
     }
+    binmode($fh);
     unless (print $fh $buf) {
         ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', 'write error', $!, 0+$!);
         return undef;
@@ -158,10 +160,11 @@ sub ap_f {
         return undef;
     }
     $! = 0;
-    unless (open($fh, '>>:raw', $fn)) {
+    unless (open($fh, '>>:raw:bytes', $fn)) {
         ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', "cannot open for appending", $!, 0+$!);
         return undef;
     }
+    binmode($fh);
     unless (print $fh $buf) {
         ($OK, $ERROR, $ERRNO, $ERRNUM) = ('ERROR', 'append error', $!, 0+$!);
         return undef;
